@@ -235,19 +235,19 @@ private:
   volatile int32_t             schedule_wait;
 
   inline bool cab_changed() 
-    {return abs(cab - clevel_ ) > 0.1;}
+    {return std::abs(cab - clevel_ ) > 0.1;}
   inline bool buffsize_changed() 
-    {return abs(bufsize - cur_bufsize) != 0;}
+    {return bufsize != cur_bufsize;}
   inline void update_cab() 
     {cab = clevel_ ; c_old_model_ = c_model_;}
   inline bool change_cab() 
-    {return abs(c_old_model_ - c_model_) > 0.1;}
+    {return std::abs(c_old_model_ - c_model_) > 0.1;}
   inline bool pre_changed() 
-    {return abs(pre - alevel_) > 0.1;}
+    {return std::abs(pre - alevel_) > 0.1;}
   inline void update_pre() 
     {pre = (alevel_);}
   inline bool val_changed() 
-    {return  abs(alevel_ - (*alevel)) > 0.1 || abs(clevel_ - (*clevel)) > 0.1 || abs(c_model_ - (*c_model)) > 0.1;}
+    {return  std::abs(alevel_ - (*alevel)) > 0.1 || abs(clevel_ - (*clevel)) > 0.1 || std::abs(c_model_ - (*c_model)) > 0.1;}
 
   // LV2 stuff
   LV2_URID_Map*                map;
