@@ -98,6 +98,148 @@ int NoiseGate::outputgate_activate(bool start, PluginDef *pdef) {
     return 0;
 }
 
+/****************************************************************
+ ** class GxSeqSettings
+ */
+
+GxSeqSettings::GxSeqSettings()
+    : seqline() {
+}
+
+GxSeqSettings& GxSeqSettings::operator=(GxSeqSettings const& seqset) {
+    seqline = seqset.seqline;
+    return *this;
+}
+
+void GxSeqSettings::writeJSON(gx_system::JsonWriter& w) const {
+    w.begin_object(true);
+    w.write_key("seq.seqline");
+    w.begin_array();
+    for (unsigned int i = 0; i < seqline.size(); i++) {
+        w.write(seqline[i]);
+    }
+    w.end_array(true);
+    w.end_object(true);
+}
+
+bool GxSeqSettings::operator==(const GxSeqSettings& seqset) const {
+    if (seqline != seqset.seqline) {
+	return false;
+    }
+    return true;
+}
+
+void GxSeqSettings::read_seqline(gx_system::JsonParser& jp) {
+    seqline.clear();
+    jp.next(gx_system::JsonParser::begin_array);
+    while (jp.peek() == gx_system::JsonParser::value_number) {
+        jp.next(gx_system::JsonParser::value_number);
+        int p = jp.current_value_int();
+        seqline.push_back(p);
+    }
+    jp.next(gx_system::JsonParser::end_array);
+}
+
+void GxSeqSettings::readJSON(gx_system::JsonParser& jp) {
+    jp.next(gx_system::JsonParser::begin_object);
+    do {
+        jp.next(gx_system::JsonParser::value_key);
+        if (jp.current_value() == "seq.seqline") {
+            read_seqline(jp);
+        } else {
+            gx_print_warning("seq settings", "unknown key: " + jp.current_value());
+            jp.skip_object();
+        }
+    } while (jp.peek() == gx_system::JsonParser::value_key);
+    jp.next(gx_system::JsonParser::end_object);
+}
+
+/****************************************************************
+ ** class SeqParameter
+ */
+
+ParameterV<GxSeqSettings>::ParameterV(const string& id, GxSeqSettings *v)
+    : Parameter(id, "", tp_special, None, true, false),
+      json_value(),
+      value(v),
+      std_value(),
+      value_storage(),
+      changed() {
+    std_value.seqline = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
+}
+
+SeqParameter *SeqParameter::insert_param(
+    ParamMap &pmap, const string& id, GxSeqSettings *v) {
+    SeqParameter *p = new SeqParameter(id, v);
+    pmap.insert(p);
+    return p;
+}
+
+SeqParameter::~ParameterV() {
+}
+
+SeqParameter::ParameterV(gx_system::JsonParser& jp)
+ : Parameter(jp_next(jp, "Parameter")),
+   json_value(),
+   value(&value_storage),
+   std_value() {
+    while (jp.peek() != gx_system::JsonParser::end_object) {
+	jp.next(gx_system::JsonParser::value_key);
+	if (jp.current_value() == "value") {
+	    value->readJSON(jp);
+	} else if (jp.current_value() == "std_value") {
+	    std_value.readJSON(jp);
+	} else {
+	    gx_print_warning(
+		"SeqParameter", Glib::ustring::compose("%1: unknown key: %2", _id, jp.current_value()));
+	    jp.skip_object();
+	}
+    }
+    jp.next(gx_system::JsonParser::end_object);
+}
+
+void SeqParameter::serializeJSON(gx_system::JsonWriter& jw) {
+    jw.begin_object();
+    jw.write_key("Parameter"); Parameter::serializeJSON(jw);
+    jw.write_key("value"); value->writeJSON(jw);
+    jw.write_key("std_value"); std_value.writeJSON(jw);
+    jw.end_object();
+}
+
+bool SeqParameter::on_off_value() {
+    assert(false);
+    return false;
+}
+
+void SeqParameter::stdJSON_value() {
+    json_value = std_value;
+}
+
+void SeqParameter::writeJSON(gx_system::JsonWriter& jw) const {
+    jw.write_key(_id.c_str());
+    value->writeJSON(jw);
+}
+
+void SeqParameter::readJSON_value(gx_system::JsonParser& jp) {
+    json_value.readJSON(jp);
+}
+
+bool SeqParameter::compareJSON_value() {
+    return json_value == *value;
+}
+
+bool SeqParameter::set(const GxSeqSettings& val) const {
+    if (val == *value) {
+	return false;
+    }
+    *value = val;
+    changed(value);
+    return true;
+}
+
+void SeqParameter::setJSON_value() {
+    set(json_value);
+}
 
 /****************************************************************
  ** class GxJConvSettings
@@ -170,7 +312,7 @@ bool GxJConvSettings::operator==(const GxJConvSettings& jcset) const {
     if (fGainCor != jcset.fGainCor) {
 	return false;
     }
-    if (fGainCor && abs(fGain - jcset.fGain) > 1e-4 * (fGain + jcset.fGain)) {
+    if (fGainCor && std::abs(fGain - jcset.fGain) > 1e-4 * (fGain + jcset.fGain)) {
 	return false;
     }
     if (gainline == jcset.gainline) {
@@ -681,6 +823,97 @@ int BaseConvolver::conv_start() {
     return conv.start(policy, priority);
 }
 
+/****************************************************************
+ ** class FixedBaseConvolver
+ */
+
+
+FixedBaseConvolver::FixedBaseConvolver(EngineControl& engine_, sigc::slot<void> sync_, gx_resample::BufferResampler& resamp)
+    : PluginDef(),
+      conv(resamp),
+      activate_mutex(),
+      engine(engine_),
+      sync(sync_),
+      activated(false),
+      SamplingFreq(0),
+      buffersize(0),
+      bz(0.0),
+      plugin() {
+    version = PLUGINDEF_VERSION;
+    set_samplerate = init;
+    activate_plugin = activate;
+    plugin = this;
+    engine.signal_buffersize_change().connect(
+	sigc::mem_fun(*this, &FixedBaseConvolver::change_buffersize));
+}
+
+FixedBaseConvolver::~FixedBaseConvolver() {
+    update_conn.disconnect();
+}
+
+void FixedBaseConvolver::change_buffersize(unsigned int bufsize) {
+    boost::mutex::scoped_lock lock(activate_mutex);
+    buffersize = bufsize;
+    conv.set_buffersize(static_cast<int>(ceil((bufsize*bz))));
+    if (activated) {
+	if (!bufsize) {
+	    conv.stop_process();
+	} else {
+	    start(true);
+	}
+    }
+}
+
+void FixedBaseConvolver::init(unsigned int samplingFreq, PluginDef *p) {
+    FixedBaseConvolver& self = *static_cast<FixedBaseConvolver*>(p);
+    boost::mutex::scoped_lock lock(self.activate_mutex);
+    self.SamplingFreq = samplingFreq;
+    self.bz = 96000/samplingFreq;
+    self.conv.set_buffersize(static_cast<int>(ceil((self.buffersize*self.bz))));
+    self.conv.set_samplerate(self.bz*self.SamplingFreq);
+    if (self.activated) {
+	self.start(true);
+    }
+}
+
+bool FixedBaseConvolver::check_update_timeout() {
+    if (!activated || !plugin.get_on_off()) {
+	return false;
+    }
+    check_update();
+    return true;
+}
+
+int FixedBaseConvolver::activate(bool start, PluginDef *p) {
+    FixedBaseConvolver& self = *static_cast<FixedBaseConvolver*>(p);
+    boost::mutex::scoped_lock lock(self.activate_mutex);
+    if (start) {
+	if (!self.conv.get_buffersize()) {
+	    start = false;
+	}
+    }
+    if (start == self.activated) {
+	return 0;
+    }
+    if (start) {
+	if (!self.start()) {
+	    return -1;
+	}
+	self.update_conn = Glib::signal_timeout().connect(
+	    sigc::mem_fun(self, &FixedBaseConvolver::check_update_timeout), 200);
+    } else {
+	self.conv.stop_process();
+    }
+    self.activated = start;
+    return 0;
+}
+
+int FixedBaseConvolver::conv_start() {
+    int policy, priority;
+    engine.get_sched_priority(policy, priority);
+    return conv.start(policy, priority);
+}
+
 /****************************************************************
  ** class CabinetConvolver
  */
@@ -765,8 +998,9 @@ static int cab_load_ui(const UiBuilder& builder, int format) {
 
 }
 
-CabinetConvolver::CabinetConvolver(EngineControl& engine, sigc::slot<void> sync, gx_resample::BufferResampler& resamp):
-    BaseConvolver(engine, sync, resamp),
+CabinetConvolver::CabinetConvolver(EngineControl& engine, sigc::slot<void> sync,
+    gx_resample::BufferResampler& resamp):
+    FixedBaseConvolver(engine, sync, resamp),
     current_cab(-1),
     level(0),
     cabinet(0),
@@ -774,7 +1008,8 @@ CabinetConvolver::CabinetConvolver(EngineControl& engine, sigc::slot<void> sync,
     treble(0),
     sum(no_sum),
     cab_names(new value_pair[cab_table_size+1]),
-    impf() {
+    impf(),
+    smp() {
     for (unsigned int i = 0; i < cab_table_size; ++i) {
 	CabEntry& cab = getCabEntry(i);
 	cab_names[i].value_id = cab.value_id;
@@ -803,6 +1038,11 @@ bool CabinetConvolver::do_update() {
     }
     CabDesc& cab = *getCabEntry(cabinet).data;
     if (current_cab == -1) {
+	unsigned int sr = getSamplingFreq();
+	unsigned int sru = 96000;
+	unsigned int fact = sru/sr;
+	
+	smp.setup(sr, fact*sr);
 	impf.init(cab.ir_sr);
     }
     float cab_irdata_c[cab.ir_count];
@@ -846,9 +1086,12 @@ void CabinetConvolver::check_update() {
 
 void CabinetConvolver::run_cab_conf(int count, float *input0, float *output0, PluginDef *p) {
     CabinetConvolver& self = *static_cast<CabinetConvolver*>(p);
-    if (!self.conv.compute(count,output0)) {
+	FAUSTFLOAT buf[self.smp.max_out_count(count)];
+	int ReCount = self.smp.up(count, output0, buf);
+    if (!self.conv.compute(ReCount,buf)) {
 	self.engine.overload(EngineControl::ov_Convolver, "cab");
     }
+	self.smp.down(buf, output0);
 }
 
 int CabinetConvolver::register_cab(const ParamReg& reg) {
@@ -862,6 +1105,7 @@ int CabinetConvolver::register_cab(const ParamReg& reg) {
 }
 
 //// STEREO /////
+#include "faust/cabinet_impulse_former_st.cc"
 
 static int cab_load_stereo_ui(const UiBuilder& builder, int format) {
     if (format & UI_FORM_GLADE) {
@@ -891,8 +1135,9 @@ static int cab_load_stereo_ui(const UiBuilder& builder, int format) {
 
 }
 
-CabinetStereoConvolver::CabinetStereoConvolver(EngineControl& engine, sigc::slot<void> sync, gx_resample::BufferResampler& resamp):
-    BaseConvolver(engine, sync, resamp),
+CabinetStereoConvolver::CabinetStereoConvolver(EngineControl& engine, sigc::slot<void> sync,
+    gx_resample::BufferResampler& resamp):
+    FixedBaseConvolver(engine, sync, resamp),
     current_cab(-1),
     level(0),
     cabinet(0),
@@ -900,7 +1145,9 @@ CabinetStereoConvolver::CabinetStereoConvolver(EngineControl& engine, sigc::slot
     treble(0),
     sum(no_sum),
     cab_names(new value_pair[cab_table_size+1]),
-    impf() {
+    impf(),
+    smp(),
+    smps() {
     for (unsigned int i = 0; i < cab_table_size; ++i) {
 	CabEntry& cab = getCabEntry(i);
 	cab_names[i].value_id = cab.value_id;
@@ -929,6 +1176,12 @@ bool CabinetStereoConvolver::do_update() {
     }
     CabDesc& cab = *getCabEntry(cabinet).data;
     if (current_cab == -1) {
+	unsigned int sr = getSamplingFreq();
+	unsigned int sru = 96000;
+	unsigned int fact = sru/sr;
+	
+	smp.setup(sr, fact*sr);
+	smps.setup(sr, fact*sr);
 	impf.init(cab.ir_sr);
     }
     float cab_irdata_c[cab.ir_count];
@@ -972,9 +1225,15 @@ void CabinetStereoConvolver::check_update() {
 
 void CabinetStereoConvolver::run_cab_conf(int count, float *input0, float *input1, float *output0, float *output1, PluginDef *p) {
     CabinetStereoConvolver& self = *static_cast<CabinetStereoConvolver*>(p);
-    if (!self.conv.compute_stereo(count,output0,output1)) {
+	FAUSTFLOAT buf[self.smp.max_out_count(count)];
+	FAUSTFLOAT buf1[self.smps.max_out_count(count)];
+	int ReCount = self.smp.up(count, output0, buf);
+	self.smps.up(count, output1, buf1);
+    if (!self.conv.compute_stereo(ReCount,buf,buf1)) {
 	self.engine.overload(EngineControl::ov_Convolver, "cab_st");
     }
+	self.smp.down(buf, output0);
+	self.smps.down(buf1, output1);
 }
 
 int CabinetStereoConvolver::register_cab(const ParamReg& reg) {
@@ -1062,8 +1321,9 @@ static int pre_load_ui(const UiBuilder& builder, int format) {
 
 }
 
-PreampConvolver::PreampConvolver(EngineControl& engine, sigc::slot<void> sync, gx_resample::BufferResampler& resamp):
-    BaseConvolver(engine, sync, resamp),
+PreampConvolver::PreampConvolver(EngineControl& engine, sigc::slot<void> sync,
+    gx_resample::BufferResampler& resamp):
+    FixedBaseConvolver(engine, sync, resamp),
     current_pre(-1),
     level(0),
     preamp(0),
@@ -1071,7 +1331,8 @@ PreampConvolver::PreampConvolver(EngineControl& engine, sigc::slot<void> sync, g
     treble(0),
     sum(no_sum),
     pre_names(new value_pair[pre_table_size+1]),
-    impf() {
+    impf(),
+    smp() {
     for (unsigned int i = 0; i < pre_table_size; ++i) {
 	PreEntry& pre = getPreEntry(i);
 	pre_names[i].value_id = pre.value_id;
@@ -1100,6 +1361,11 @@ bool PreampConvolver::do_update() {
     }
     PreDesc& pre = *getPreEntry(preamp).data;
     if (current_pre == -1) {
+	unsigned int sr = getSamplingFreq();
+	unsigned int sru = 96000;
+	unsigned int fact = sru/sr;
+	
+	smp.setup(sr, fact*sr);
 	impf.init(pre.ir_sr);
     }
     float pre_irdata_c[pre.ir_count];
@@ -1143,9 +1409,12 @@ void PreampConvolver::check_update() {
 
 void PreampConvolver::run_pre_conf(int count, float *input0, float *output0, PluginDef *p) {
     PreampConvolver& self = *static_cast<PreampConvolver*>(p);
-    if (!self.conv.compute(count, output0)) {
+	FAUSTFLOAT buf[self.smp.max_out_count(count)];
+	int ReCount = self.smp.up(count, output0, buf);
+     if (!self.conv.compute(ReCount, buf)) {
 	self.engine.overload(EngineControl::ov_Convolver, "pre");
     }
+	self.smp.down(buf, output0);
 }
 
 int PreampConvolver::register_pre(const ParamReg& reg) {
@@ -1164,11 +1433,13 @@ int PreampConvolver::register_pre(const ParamReg& reg) {
 
 #include "faust/presence_level.cc"
 
-ContrastConvolver::ContrastConvolver(EngineControl& engine, sigc::slot<void> sync, gx_resample::BufferResampler& resamp):
-    BaseConvolver(engine, sync, resamp),
+ContrastConvolver::ContrastConvolver(EngineControl& engine, sigc::slot<void> sync,
+    gx_resample::BufferResampler& resamp):
+    FixedBaseConvolver(engine, sync, resamp),
     level(0),
     sum(no_sum),
-    presl() {
+    presl(),
+    smp() {
     id = "con";
     name = N_("Contrast convolver");
     mono_audio = run_contrast;
@@ -1186,6 +1457,11 @@ bool ContrastConvolver::do_update() {
 	conv.stop_process();
     }
     if (configure) {
+	unsigned int sr = getSamplingFreq();
+	unsigned int sru = 96000;
+	unsigned int fact = sru/sr;
+	
+	smp.setup(sr, fact*sr);
 	presl.init(contrast_ir_desc.ir_sr);
     }
     float contrast_irdata_c[contrast_ir_desc.ir_count];
@@ -1234,9 +1510,13 @@ int ContrastConvolver::register_con(const ParamReg& reg) {
 
 void ContrastConvolver::run_contrast(int count, float *input0, float *output0, PluginDef *p) {
     ContrastConvolver& self = *static_cast<ContrastConvolver*>(p);
-    if (!self.conv.compute(count,output0)) {
+	FAUSTFLOAT buf[self.smp.max_out_count(count)];
+	int ReCount = self.smp.up(count, output0, buf);
+    if (!self.conv.compute(ReCount,buf)) {
 	self.engine.overload(EngineControl::ov_Convolver, "contrast");
     }
+	self.smp.down(buf, output0);
+    
 }
 
 /****************************************************************
@@ -1251,6 +1531,12 @@ void ContrastConvolver::run_contrast(int count, float *input0, float *output0, P
 
 #include "gx_record.cc"
 
+/****************************************************************
+ ** class DrumSequencer
+ */
+
+#include "gx_drumseq.cc"
+
 
 /****************************************************************************
 *
