@@ -179,7 +179,8 @@ void MidiController::writeJSON(gx_system::JsonWriter& jw) const {
         jw.write(_upper);
     } else {
         assert(param->getControlType() == Parameter::Switch);
-	jw.write(toggle);
+        jw.write(toggle);
+        jw.write(_toggle_behaviour);
     }
     jw.end_array();
 }
@@ -197,60 +198,68 @@ MidiController *MidiController::readJSON(gx_system::JsonParser& jp, ParamMap& pm
     Parameter& pm = pmap[id];
     float lower = 0, upper = 0;
     bool toggle = false;
+    int toggle_behaviour = 0;
     bool bad = false;
     bool chg = false;
     if (pm.getControlType() == Parameter::Continuous ||
         pm.getControlType() == Parameter::Enum) {
         if (jp.peek() == gx_system::JsonParser::value_number) {
-	    jp.next(gx_system::JsonParser::value_number);
-	    if (jp.peek() == gx_system::JsonParser::value_number) {
-		// two numbers -> range
-		float pmin, pmax;
-		if (pm.hasRange()) {
-		    pmin = pm.getLowerAsFloat();
-		    pmax = pm.getUpperAsFloat();
-		} else {
-		    bad = true;
-		    pmin = pmax = 0;
-		}
-		lower = jp.current_value_float();
-		jp.next(gx_system::JsonParser::value_number);
-		upper = jp.current_value_float();
-		if (lower > pmax) {
-		    lower = pmax;
-		    chg = true;
-		} else if (lower < pmin) {
-		    lower = pmin;
-		    chg = true;
-		}
-		if (upper > pmax) {
-		    upper = pmax;
-		    chg = true;
-		} else if (upper < pmin) {
-		    upper = pmin;
-		    chg = true;
-		}
-	    } else {
-		// just one number -> switch (new format)
-		bad = true;
-	    }
-	} else {
-	    // no number -> switch (old format)
-	    bad = true;
-	}
+            jp.next(gx_system::JsonParser::value_number);
+            if (jp.peek() == gx_system::JsonParser::value_number) {
+                // two numbers -> range
+                float pmin, pmax;
+                if (pm.hasRange()) {
+                    pmin = pm.getLowerAsFloat();
+                    pmax = pm.getUpperAsFloat();
+                } else {
+                    bad = true;
+                    pmin = pmax = 0;
+                }
+                lower = jp.current_value_float();
+                jp.next(gx_system::JsonParser::value_number);
+                upper = jp.current_value_float();
+                if (lower > pmax) {
+                    lower = pmax;
+                    chg = true;
+                } else if (lower < pmin) {
+                    lower = pmin;
+                    chg = true;
+                }
+                if (upper > pmax) {
+                    upper = pmax;
+                    chg = true;
+                } else if (upper < pmin) {
+                    upper = pmin;
+                    chg = true;
+                }
+            } else {
+                // just one number -> switch (new format)
+                bad = true;
+            }
+        } else {
+            // no number -> switch (old format)
+            bad = true;
+        }
     } else if (pm.getControlType() == Parameter::Switch) {
-	if (jp.peek() == gx_system::JsonParser::value_number) {
-	    jp.next(gx_system::JsonParser::value_number);
-	    if (jp.peek() == gx_system::JsonParser::value_number) {
-		// two numbers -> range
-		bad = true;
-	    } else {
-		toggle = jp.current_value_int();
-	    }
-	}
+        if (jp.peek() == gx_system::JsonParser::value_number) {
+            jp.next(gx_system::JsonParser::value_number);
+            int _toggle = jp.current_value_int();
+            if (jp.peek() == gx_system::JsonParser::value_number) {
+                jp.next(gx_system::JsonParser::value_number);
+                if (jp.current_value_int() < Parameter::toggle_type::_Count) {
+                   toggle = _toggle;
+                   toggle_behaviour = jp.current_value_int();
+                } else {
+                   // two numbers -> range
+                   bad = true;
+                }
+            } else {
+                toggle = _toggle;
+            }
+        }
     } else {
-	// bad control type
-	bad = true;
+        // bad control type
+        bad = true;
     }
     assert(jp.peek() == gx_system::JsonParser::end_array);
     while (jp.next() != gx_system::JsonParser::end_array); // be tolerant (non-debug mode)
@@ -265,28 +274,42 @@ MidiController *MidiController::readJSON(gx_system::JsonParser& jp, ParamMap& pm
             _("recall MIDI state"),
             _("Parameter range outside bounds, changed: ") + id);
     }
-    return new MidiController(pm, lower, upper, toggle);
+    return new MidiController(pm, lower, upper, toggle, toggle_behaviour);
 }
 
 bool MidiController::set_midi(int n, int last_value) {
     bool ret = false;
     if (param->get_midi_blocked()) return ret;
     if (toggle) {
-	bool s_o = (2*last_value > 127);
-	bool s_n = (2*n > 127);
-	if (!s_o && s_n) {
-	    if (param->on_off_value()) {
-		ret = param->midi_set(0, 127, _lower, _upper);
-	    } else {
-		ret = param->midi_set(127, 127, _lower, _upper);
-	    }
-	}
+        switch (_toggle_behaviour) {
+            case Parameter::toggle_type::OnOff: {
+                bool s_o = (2*last_value > 127);
+                bool s_n = (2*n > 127);
+                if (!s_o && s_n) {
+                    if (param->on_off_value()) {
+                        ret = param->midi_set(0, 127, _lower, _upper);
+                    } else {
+                        ret = param->midi_set(127, 127, _lower, _upper);
+                    }
+                }
+                break;
+            }
+            case Parameter::toggle_type::Constant: {
+                if (n == last_value || last_value == -1) {
+                    if (param->on_off_value()) {
+                        ret = param->midi_set(0, n, _lower, _upper);
+                    } else {
+                        ret = param->midi_set(127, n, _lower, _upper);
+                    }
+                }
+                break;
+            }
+        }
     } else {
         //fprintf(stderr,"continues %s \n",param->id().c_str());
         //fprintf(stderr,"%f \n",(127.*log10f(double(n+1.)))/2.1072);
         //fprintf(stderr,"%f \n",double(n * double(double(n+1.)/128)));
-        
-	ret = param->midi_set(n, 127, _lower, _upper);
+        ret = param->midi_set(n, 127, _lower, _upper);
     }
     param->trigger_changed();
     return ret;
@@ -298,7 +321,7 @@ bool MidiController::set_trans(int n, int last_value) {
     if (strcmp(param->id().c_str(), "engine.mute")==0) {
         if ( n == 0) n = 127;
         else n = 0;
-    } 
+    }
     ret = param->midi_set(n, 127, _lower, _upper);
     return ret;
 }
@@ -446,6 +469,7 @@ MidiControllerList::MidiControllerList()
     : map(),
       last_midi_control_value(),
       last_midi_control(-2),
+      changed_midi_control_value(),
       program_change(-1),
       mute_change(-1),
       bank_change(-1),
@@ -462,6 +486,7 @@ MidiControllerList::MidiControllerList()
       midi_value_changed() {
     for (int i = 0; i < ControllerArray::array_size; ++i) {
 	last_midi_control_value[i] = -1;
+	changed_midi_control_value[i] = 0;
     }
     pgm_chg.connect(sigc::mem_fun(*this, &MidiControllerList::on_pgm_chg));
     mute_chg.connect(sigc::mem_fun(*this, &MidiControllerList::on_mute_chg));
@@ -473,16 +498,21 @@ MidiControllerList::MidiControllerList()
 bool MidiControllerList::check_midi_values() {
     static int saved_values[ControllerArray::array_size];
     for (unsigned int n = 0; n < ControllerArray::array_size; ++n) {
-	if (saved_values[n] != last_midi_control_value[n]) {
-	    saved_values[n] = last_midi_control_value[n];
-	    midi_value_changed(n, saved_values[n]);
-	    if (!get_config_mode()) {
-		midi_controller_list& ctr_list = map[n];
-		for (midi_controller_list::iterator i = ctr_list.begin(); i != ctr_list.end(); ++i) {
-		    i->trigger_changed();
-		}
-	    }
-	}
+        if (changed_midi_control_value[n]) {
+            changed_midi_control_value[n] = 0;
+            saved_values[n] = last_midi_control_value[n];
+            midi_value_changed(n, saved_values[n]);
+            if (!get_config_mode()) {
+                midi_controller_list& ctr_list = map[n];
+                for (midi_controller_list::iterator i = ctr_list.begin(); i != ctr_list.end(); ++i) {
+                    if (i->is_toggle()
+                        && i->toggle_behaviour() == Parameter::toggle_type::Constant) {
+                        midi_value_changed(n, i->getParameter().on_off_value() * 127);
+                    }
+                    i->trigger_changed();
+                }
+            }
+        }
     }
     return true;
 }
@@ -551,7 +581,7 @@ void MidiControllerList::deleteParameter(Parameter& p) {
 }
 
 void MidiControllerList::modifyCurrent(Parameter &param,
-                                       float lower, float upper, bool toggle) {
+                                       float lower, float upper, bool toggle, int toggle_behaviour) {
     if (!get_config_mode()) {
 	assert(false);
 	return;	// keep rt thread away from table
@@ -561,17 +591,21 @@ void MidiControllerList::modifyCurrent(Parameter &param,
     if (last_midi_control < 0)
         return;
     // add zone to controller
-    map[last_midi_control].push_front(MidiController(param, lower, upper, toggle));
+    map[last_midi_control].push_front(MidiController(param, lower, upper, toggle, toggle_behaviour));
     update_from_controller(last_midi_control);
     changed();
 }
 
 void MidiControllerList::request_midi_value_update() {
     for (unsigned int n = 0; n < ControllerArray::array_size; ++n) {
-	int v = last_midi_control_value[n];
-	if (v >= 0) {
-	    midi_value_changed(n, v);
-	}
+        int v = last_midi_control_value[n];
+        midi_controller_list& ctr_list = map[n];
+        for (midi_controller_list::iterator i = ctr_list.begin(); i != ctr_list.end(); ++i) {
+            if (i->is_toggle()) {
+                v = i->getParameter().on_off_value() * 127;
+            }
+            midi_value_changed(n, v);
+        }
     }
 }
 
@@ -582,7 +616,7 @@ void MidiControllerList::set_ctr_val(int ctr, int val) {
         midi_controller_list& ctr_list = map[ctr];
         for (midi_controller_list::iterator i = ctr_list.begin(); i != ctr_list.end(); ++i) {
             i->set_midi(val, get_last_midi_control_value(ctr));
-	}
+        }
     }
     MidiControllerList::set_last_midi_control_value(ctr, val);
 }
@@ -1127,14 +1161,14 @@ void FloatParameter::writeJSON(gx_system::JsonWriter& jw) const {
 void FloatParameter::readJSON_value(gx_system::JsonParser& jp) {
     jp.next(gx_system::JsonParser::value_number);
     json_value = jp.current_value_float();
-    if (json_value < lower-abs(5*FLT_EPSILON*lower) || json_value > upper+abs(5*FLT_EPSILON*upper)) {
+    if (json_value < lower-std::abs(5*FLT_EPSILON*lower) || json_value > upper+std::abs(5*FLT_EPSILON*upper)) {
 	range_warning(json_value, lower, upper);
 	json_value = std_value;
     }
 }
 
 bool FloatParameter::compareJSON_value() {
-    return abs(json_value - *value) < 5*FLT_EPSILON;
+    return std::abs(json_value - *value) < 5*FLT_EPSILON;
 }
 
 void FloatParameter::setJSON_value() {
@@ -1732,7 +1766,6 @@ void StringParameter::setJSON_value() {
     set(json_value);
 }
 
-
 /****************************************************************
  ** Parameter Map
  */
@@ -1769,6 +1802,8 @@ void ParamMap::writeJSON_one(gx_system::JsonWriter& jw, Parameter *p) {
 	jw.write("String");
     } else if (dynamic_cast<JConvParameter*>(p) != 0) {
 	jw.write("JConv");
+    } else if (dynamic_cast<SeqParameter*>(p) != 0) {
+	jw.write("Seq");
     } else {
 #ifndef NDEBUG
 	cerr << "skipping " << p->id() << endl;
@@ -1804,6 +1839,8 @@ Parameter *ParamMap::readJSON_one(gx_system::JsonParser& jp) {
 	return insert(new StringParameter(jp));
     } else if (jp.current_value() == "JConv") {
 	return insert(new JConvParameter(jp));
+    } else if (jp.current_value() == "Seq") {
+	return insert(new SeqParameter(jp));
     } else {
 	gx_print_warning(
 	    "ParamMap", Glib::ustring::compose("unknown parameter type: %1", jp.current_value()));
