@@ -970,7 +970,7 @@ void CmdConnection::notify(gx_system::JsonStringWriter& jw, const methodnames *m
     PROCEDURE(midi_modifyCurrent) {
 	serv.jack.get_engine().controller_map.modifyCurrent(
 	    serv.settings.get_param()[params[0]->getString()], params[1]->getFloat(),
-	    params[2]->getFloat(), params[3]->getInt());
+	    params[2]->getFloat(), params[3]->getInt(), params[4]->getInt());
     }
 
     PROCEDURE(set) {
@@ -1013,6 +1013,11 @@ void CmdConnection::notify(gx_system::JsonStringWriter& jw, const methodnames *m
 		    gx_system::JsonSubParser jps = v->getSubParser();
 		    s.readJSON(jps);
 		    dynamic_cast<gx_engine::JConvParameter*>(&p)->set(s);
+		} else if (dynamic_cast<gx_engine::SeqParameter*>(&p) != 0) {
+		    gx_engine::GxSeqSettings s;
+		    gx_system::JsonSubParser jps = v->getSubParser();
+		    s.readJSON(jps);
+		    dynamic_cast<gx_engine::SeqParameter*>(&p)->set(s);
 		} else {
 		    throw RpcError(-32602, "Invalid param -- unknown variable");
 		}
@@ -1046,6 +1051,10 @@ void CmdConnection::notify(gx_system::JsonStringWriter& jw, const methodnames *m
 	serv.save_state();
     }
 
+    PROCEDURE(set_online_presets) {
+	serv.settings.load_online_presets();
+    }
+
     PROCEDURE(sendcc) {
 	serv.jack.send_midi_cc(params[0]->getInt(),params[1]->getInt(),params[2]->getInt(),params[3]->getInt());
     }
@@ -1876,6 +1885,11 @@ void GxService::connect_value_changed_signal(gx_engine::Parameter *p) {
 	    sigc::hide(
 		sigc::bind(
 		    sigc::mem_fun(this, &GxService::on_param_value_changed), p)));
+    } else if (dynamic_cast<gx_engine::SeqParameter*>(p) != 0) {
+	dynamic_cast<gx_engine::SeqParameter*>(p)->signal_changed().connect(
+	    sigc::hide(
+		sigc::bind(
+		    sigc::mem_fun(this, &GxService::on_param_value_changed), p)));
     }
 }
 
@@ -1911,6 +1925,8 @@ void GxService::on_param_value_changed(gx_engine::Parameter *p) {
 	jw->write(p->getString().get_value());
     } else if (dynamic_cast<gx_engine::JConvParameter*>(p) != 0) {
 	dynamic_cast<gx_engine::JConvParameter*>(p)->get_value().writeJSON(*jw);
+    } else if (dynamic_cast<gx_engine::SeqParameter*>(p) != 0) {
+	dynamic_cast<gx_engine::SeqParameter*>(p)->get_value().writeJSON(*jw);
     } else {
 	assert(false);
     }
