@@ -212,10 +212,11 @@ void MidiConnect::midi_response_cb(GtkWidget *widget, gint response_id, gpointer
             assert(m->adj_upper);
             float lower = gtk_adjustment_get_value(m->adj_lower);
             float upper = gtk_adjustment_get_value(m->adj_upper);
-            m->machine.midi_modifyCurrent(m->param, lower, upper, false);
+            m->machine.midi_modifyCurrent(m->param, lower, upper, false, gx_engine::Parameter::toggle_type::OnOff);
         } else {
-	    bool toggle = gtk_toggle_button_get_active(m->use_toggle);
-            m->machine.midi_modifyCurrent(m->param, 0, 0, toggle);
+            bool toggle = gtk_toggle_button_get_active(m->use_toggle);
+            int toggle_behaviour = gtk_combo_box_get_active(GTK_COMBO_BOX(m->toggle_behaviours));
+            m->machine.midi_modifyCurrent(m->param, 0, 0, toggle, toggle_behaviour);
         }
         break;
     case RESPONSE_DELETE:
@@ -261,6 +262,12 @@ void MidiConnect::midi_destroy_cb(GtkWidget *widget, gpointer data) {
     m->machine.midi_set_config_mode(false);
 }
 
+void MidiConnect::toggle_behaviours_visibility(GtkWidget *widget, gpointer data) {
+    MidiConnect *m = reinterpret_cast<MidiConnect*>(data);
+    int b = gtk_toggle_button_get_active(m->use_toggle);
+    gtk_widget_set_sensitive(gtk_widget_get_parent(m->toggle_behaviours), b);
+}
+
 const char* MidiConnect::ctl_to_str(int n) {
     static char buf[12];
     if (n < 0)
@@ -336,6 +343,7 @@ MidiConnect::MidiConnect(GdkEventButton *event, gx_engine::Parameter &param_, gx
     GtkBuilder * builder = gtk_builder_new();
     dialog = gx_gui::load_toplevel(builder, "midi.glade", "MidiConnect");
     use_toggle = GTK_TOGGLE_BUTTON(gtk_builder_get_object(builder, "use_toggle"));
+    toggle_behaviours = GTK_WIDGET(gtk_builder_get_object(builder, "toggle_behaviours"));
     GtkWidget *zn = GTK_WIDGET(gtk_builder_get_object(builder, "zone_name"));
     GtkStyle *style = gtk_widget_get_style(zn);
     pango_font_description_set_size(style->font_desc, 12*PANGO_SCALE);
@@ -370,19 +378,40 @@ MidiConnect::MidiConnect(GdkEventButton *event, gx_engine::Parameter &param_, gx
             gtk_adjustment_set_value(adj_lower, pctrl->lower());
             gtk_adjustment_set_value(adj_upper, pctrl->upper());
         }
-        gtk_widget_hide(GTK_WIDGET(use_toggle));
+        gtk_widget_hide(gtk_widget_get_parent(gtk_widget_get_parent(GTK_WIDGET(use_toggle))));
     } else {
         gtk_widget_hide(GTK_WIDGET(gtk_builder_get_object(builder, "range_label")));
         gtk_widget_hide(GTK_WIDGET(gtk_builder_get_object(builder, "range_box")));
+
+        store = GTK_LIST_STORE(gtk_builder_get_object(builder, "liststore2"));
+        GtkTreeIter iter;
+        gtk_list_store_clear(store);
+        for (std::map<gx_engine::Parameter::toggle_type, const char*>::iterator it = toggle_behaviour_descriptions.begin();
+               it!=toggle_behaviour_descriptions.end(); ++it) {
+                gtk_list_store_append(store, &iter);
+                gtk_list_store_set(store, &iter, 0, it->first, 1, it->second, -1);
+        }
+        gtk_combo_box_set_model(GTK_COMBO_BOX(toggle_behaviours), GTK_TREE_MODEL(store));
+        //g_object_unref(store); // this THROW A GLib-GObject-CRITICAL WARNING
+        GtkCellRenderer *renderer = gtk_cell_renderer_text_new();
+        gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(toggle_behaviours), renderer, TRUE);
+        gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(toggle_behaviours), renderer,
+                                       "cell-background", 0, "text", 1, NULL);
+        gtk_combo_box_set_active(GTK_COMBO_BOX(toggle_behaviours), gx_engine::Parameter::toggle_type::OnOff);
         if (nctl != -1) {
-	    gtk_toggle_button_set_active(use_toggle, pctrl->is_toggle());
-	}
+            gtk_toggle_button_set_active(use_toggle, pctrl->is_toggle());
+            gtk_combo_box_set_active(GTK_COMBO_BOX(toggle_behaviours), pctrl->toggle_behaviour());
+        }
+        int b = gtk_toggle_button_get_active(use_toggle);
+        gtk_widget_set_sensitive(gtk_widget_get_parent(toggle_behaviours), b);
     }
     entry_new = GTK_WIDGET(gtk_builder_get_object(builder, "new"));
     label_desc = GTK_WIDGET(gtk_builder_get_object(builder, "new_desc"));
+
     g_signal_connect(dialog, "response", G_CALLBACK(midi_response_cb), this);
     g_signal_connect(dialog, "destroy", G_CALLBACK(midi_destroy_cb), this);
     g_signal_connect(entry_new, "changed", G_CALLBACK(changed_text_handler), this);
+    g_signal_connect(use_toggle, "toggled", G_CALLBACK(toggle_behaviours_visibility), this);
     if (nctl == -1) {
         gtk_dialog_set_response_sensitive(GTK_DIALOG(dialog), RESPONSE_DELETE, FALSE);
         gtk_dialog_set_response_sensitive(GTK_DIALOG(dialog), GTK_RESPONSE_OK, FALSE);
