@@ -81,13 +81,10 @@ PresetWindow::PresetWindow(Glib::RefPtr<gx_gui::GxBuilder> bld, gx_engine::GxMac
     //actiongroup->add(act, sigc::mem_fun(*this, &PresetWindow::on_presets_close));
     //gtk_activatable_set_related_action(GTK_ACTIVATABLE(close_preset->gobj()), act->gobj());
     close_preset->hide(); // disable (maybe remove later)
-#ifdef HAVE_WEBKIT
     actions.online_preset_bank = Gtk::Action::create("OnlineBank");
     actions.group->add(actions.online_preset_bank, sigc::mem_fun(*this, &PresetWindow::on_online_preset));
     gtk_activatable_set_related_action(GTK_ACTIVATABLE(online_preset->gobj()), actions.online_preset_bank->gobj());
-#else
-    online_preset->set_sensitive(false);
-#endif
+   // if (!machine.get_jack()) online_preset->set_sensitive(false);
     bank_treeview->set_model(Gtk::ListStore::create(bank_col));
     bank_treeview->set_name("PresetView");
     bank_treeview->get_selection()->set_select_function(
@@ -696,121 +693,231 @@ void PresetWindow::on_new_bank() {
     start_edit(m->get_path(edit_iter), *bank_treeview->get_column(1), *bank_cellrenderer);
 }
 
-#ifdef HAVE_WEBKIT
+// Online Preset Downloader
 
-bool PresetWindow::insertRequested(const char *ur, gpointer data)
-{
-    PresetWindow& self = *reinterpret_cast<PresetWindow*>(data);
-	const char *file_name = strrchr( ur, '/' ) + 1;
-    const gchar* dest = g_strdup_printf("file:///tmp/%s",file_name);
-    //fprintf(stderr,"insert %s\n",dest);
-    Glib::RefPtr<Gtk::ListStore> ls = Glib::RefPtr<Gtk::ListStore>::cast_dynamic(self.bank_treeview->get_model());
-    gx_system::PresetFileGui *f = self.machine.bank_insert_uri(dest, false);
-    if (f) {
-        Gtk::TreeIter i = ls->prepend();
-        self.set_row_for_presetfile(i,f);
-        self.bank_treeview->set_cursor(ls->get_path(i));
-        self.bank_treeview->get_selection()->select(i);
-    }
-    return TRUE;
+void DownloadWatch::start () {
+    cancellable = Gio::Cancellable::create ();
+    file_state = sigc::ptr_fun(&f_progress);
+    watcher = Glib::Thread::create(sigc::mem_fun(*this, &DownloadWatch::watch), true);
 }
 
-void PresetWindow::download_status(GObject* object, GParamSpec* pspec, gpointer data) { 
-    WebKitDownload *download;
-    WebKitDownloadStatus status;
-    const char *uri;
-
-    download = WEBKIT_DOWNLOAD(object);
-    status = webkit_download_get_status(download);
-    uri = webkit_download_get_uri(download);
-
-    switch (status) {
-      case WEBKIT_DOWNLOAD_STATUS_ERROR:
-          gx_print_error(_("Download Status"),
-            boost::format(_("ERROR download %1%")) % uri);
-          break;
-      case WEBKIT_DOWNLOAD_STATUS_CREATED:
-          //printf("download created: %s\n", uri);
-          break;
-      case WEBKIT_DOWNLOAD_STATUS_STARTED:
-          //printf("download started: %s\n", uri);
-          break;
-      case WEBKIT_DOWNLOAD_STATUS_CANCELLED:
-           gx_print_info(_("Download Status"),
-            boost::format(_("download cancelled %1%")) % uri);
-          break;
-      case WEBKIT_DOWNLOAD_STATUS_FINISHED:
-          gx_print_info(_("Download Status"),
-            boost::format(_("download finished %1%")) % uri);
-          insertRequested(uri, data);
-          break;
-      default:
-          g_assert_not_reached();
+void DownloadWatch::watch () {
+    while(true) {
+        {
+          Glib::Mutex::Lock lock (w_mutex);
+          if (stop) break;
+        }
+        sleep(15); // time out for the server response
+        cancellable->cancel();
+        if (!stop) timeout();
+        break;
     }
 }
 
-bool PresetWindow::downloadRequested(WebKitWebView* webView, WebKitDownload *download, gpointer data)
+void DownloadWatch::f_progress(goffset read, goffset total)
 {
-    const char *ur = webkit_download_get_uri (download);
-    const char *file_name = strrchr( ur, '/' ) + 1;
-    const gchar* dest = g_strdup_printf("file:///tmp/%s",file_name); 
-    webkit_download_set_destination_uri(download, dest);
-    g_signal_connect(download, "notify::status", G_CALLBACK(download_status), data);
-    return TRUE;
+    if(Gtk::Main::events_pending())
+        Gtk::Main::iteration(false); 
+  //std::cout << read << "/" << total << std::endl;
 }
 
-bool PresetWindow::uploadRequested(WebKitWebView* webView, WebKitFileChooserRequest *request,gpointer data )
-{
-    Gtk::FileChooserDialog d( "Select upload file");
-    d.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
-    d.add_button(Gtk::Stock::OK, Gtk::RESPONSE_OK);
-    d.add_shortcut_folder(string(getenv("HOME")) + string("/.config/guitarix/bamks"));
-    Gtk::FileFilter banks;
-    banks.set_name("Bank Files");
-    banks.add_pattern("*.gx");
-    d.add_filter(banks);
-    Gtk::FileFilter all;
-    all.add_pattern("*");
-    all.set_name("All Files");
-    d.add_filter(all);
-    d.set_current_folder(string(getenv("HOME")) + string("/.config/guitarix/banks"));
-
-    if (d.run() != Gtk::RESPONSE_OK) {
-        return FALSE;
+DownloadWatch::~DownloadWatch() {
+    {
+        Glib::Mutex::Lock lock (w_mutex);
+        stop = true;
+    }
+    if (watcher) watcher->join(); 
+}
+
+void PresetWindow::go_watch () {
+    if(watch != NULL) return;
+    watch = new DownloadWatch();
+    watch->timeout.connect(sigc::mem_fun(*this, &PresetWindow::watch_done));
+    watch->start();
+}
+
+void PresetWindow::watch_done() {
+    if(watch == NULL) return;
+    delete watch;
+    watch = NULL;
+}
+
+Glib::ustring PresetWindow::resolve_hostname() {
+    static Glib::ustring hostname = "localhost";
+    if (! machine.get_jack()) {
+        hostname = Gio::Resolver::get_default()->lookup_by_address
+        (Gio::InetAddress::create( machine.get_options().get_rpcaddress()));
+    }
+    return hostname;
+}
+
+bool PresetWindow::download_file(Glib::ustring from_uri, Glib::ustring to_path) {
+
+    go_watch();
+    Glib::RefPtr<Gio::File> rem = Gio::File::create_for_uri(from_uri);
+    Glib::RefPtr<Gio::File> dest = Gio::File::create_for_uri(Glib::filename_to_uri(to_path, resolve_hostname()));
+    try {
+        rem->copy(dest, watch->file_state, watch->cancellable,Gio::FILE_COPY_OVERWRITE);
+    } catch (Gio::Error& e) {
+        if (watch->cancellable->is_cancelled()) {
+            gx_print_error( _("Time out, download cancelled"), _("the server on https://musical-artifacts.com/ takes to long to respond"));
+        } else {
+            gx_print_error(e.what().c_str(), Glib::ustring::compose("can't download '%1 ' from https://musical-artifacts.com/", from_uri));
+            if (watch) watch_done();
+        }
+        return false;
+    }
+    if (watch) watch_done();
+    return true;
+}
+
+void PresetWindow::downloadPreset(Gtk::Menu *presetMenu,std::string uri) {
+
+    std::string::size_type n = uri.find_last_of('/');
+    if (n != std::string::npos) {
+        std::string fn = uri.substr(n);
+        std::string ff = "/tmp"+fn;
+
+        if (download_file(uri, ff)) {
+            Glib::RefPtr<Gtk::ListStore> ls = Glib::RefPtr<Gtk::ListStore>::cast_dynamic(bank_treeview->get_model());
+            gx_system::PresetFileGui *f = machine.bank_insert_uri(Glib::filename_to_uri(ff, resolve_hostname()), false);
+            if (f) {
+                Gtk::TreeIter i = ls->prepend();
+                set_row_for_presetfile(i,f);
+                bank_treeview->set_cursor(ls->get_path(i));
+                bank_treeview->get_selection()->select(i);
+            }
+        }
+    } else {
+        gx_print_error("downloadPreset", _("can't download preset from https://musical-artifacts.com/"));
+    }
+}
+
+void PresetWindow::read_preset_menu() {
+
+    Glib::RefPtr<Gio::File> dest = Gio::File::create_for_uri(Glib::filename_to_uri(options.get_online_presets_filename(), resolve_hostname()));
+    Glib::RefPtr<Gio::DataInputStream> in = Gio::DataInputStream::create(dest->read());    
+    
+    std::string NAME_;
+    std::string FILE_;
+    std::string INFO_;
+    std::string line;
+    bool set_name = false;
+    bool set_file = false;
+    bool set_info = false;
+    while ( in->read_line(line) )
+    {
+        if (line.find("<<NAME>>") != string::npos) {
+            set_name = true;
+            set_file = false;
+            set_info = false;
+            NAME_ = "";
+            continue;
+        } else if (line.find("<<FILE>>") != string::npos ) {
+            set_name = false;
+            set_file = true;
+            set_info = false;
+            FILE_ = "";
+            continue;
+        } else if  (line.find("<<INFO>>") != string::npos ) {
+            set_name = false;
+            set_file = false;
+            set_info = true;
+            INFO_ = "";
+            continue;
+        } else if  (line.find("<<END>>") != string::npos ) {
+            set_name = false;
+            set_file = false;
+            set_info = false;
+            olp.push_back(std::tuple<std::string,std::string,std::string>(NAME_,FILE_,INFO_));
+            NAME_ = "";
+            FILE_ = "";
+            INFO_ = "";
+            continue;
+        } 
+        if ( set_name ) NAME_ += line;
+        else if ( set_file ) FILE_ += line;
+        else if ( set_info ) INFO_ += line+"\n";
+    }
+    in->close ();
+}
+
+void PresetWindow::popup_pos( int& x, int& y, bool& push_in ){
+    online_preset->get_window()->get_origin( x, y );
+    x +=150;
+    y -= 450;
+    push_in = false;
+}
+ 
+void PresetWindow::create_preset_menu(bool is_new) {
+
+    static bool read_new = true;
+    if (read_new || is_new) {
+        read_preset_menu();
+        read_new = false;
+    }
+   
+    Gtk::MenuItem* item;
+    Gtk::Menu *presetMenu = Gtk::manage(new Gtk::Menu());
+    presetMenu->set_size_request (-1, 600);
+    for(std::vector<std::tuple<std::string,std::string,std::string> >::iterator it = olp.begin(); it != olp.end(); it++) {
+        item = Gtk::manage(new Gtk::MenuItem(get<0>(*it), true));
+        item->set_tooltip_text(get<2>(*it));
+        std::string f = get<1>(*it);
+        item->signal_activate().connect(sigc::bind(sigc::bind(sigc::mem_fun(
+          *this, &PresetWindow::downloadPreset),f),presetMenu));
+        presetMenu->append(*item);
+            
+    }
+    presetMenu->show_all();
+    presetMenu->popup(Gtk::Menu::SlotPositionCalc(sigc::mem_fun(
+       *this, &PresetWindow::popup_pos ) ),0,gtk_get_current_event_time());
+}
+
+void PresetWindow::replace_inline(std::string& subject, const std::string& search,
+                          const std::string& replace) {
+    size_t pos = 0;
+    while ((pos = subject.find(search, pos)) != std::string::npos) {
+         subject.replace(pos, search.length(), replace);
+         pos += replace.length();
     }
-    Glib::ustring  filename = d.get_filename();
-    const gchar*  f[2] = {filename.c_str(),0};
-    webkit_file_chooser_request_select_files (request, f);
-    return TRUE;
 }
 
 void PresetWindow::show_online_preset() {
 
-  Gtk::Window *window = new Gtk::Window();
-  Gtk::ScrolledWindow *scrollbox = Gtk::manage(new Gtk::ScrolledWindow());
-  scrollbox->set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
-  window->set_default_size( 800, 500 );
-  WebKitWebView * web_view =  WEBKIT_WEB_VIEW( webkit_web_view_new() );
-  WebKitWebSettings *settings = webkit_web_settings_new ();
-  g_object_set (G_OBJECT(settings), "enable-offline-web-application-cache", TRUE, NULL);
-  g_object_set (G_OBJECT(settings), "enable-page-cache", TRUE, NULL);
-  webkit_web_view_set_settings (WEBKIT_WEB_VIEW(web_view), settings);
-  
-
-  scrollbox->add(*Gtk::manage(( Glib::wrap(GTK_WIDGET(web_view )))));
-  window->add(*Gtk::manage(scrollbox));
-  webkit_web_view_load_uri(web_view, "https://api.musical-artifacts.com/guitarix-presets/");
-  g_signal_connect(G_OBJECT (web_view), "download-requested", G_CALLBACK(downloadRequested), this);
-  g_signal_connect(G_OBJECT (web_view), "run-file-chooser", G_CALLBACK(uploadRequested), this);
-  window->show_all();
+    Glib::RefPtr<Gio::File> dest = Gio::File::create_for_uri(Glib::filename_to_uri(options.get_online_presets_filename(), resolve_hostname()));
+    static bool load_new = true;
+    static bool load = false;
+    Glib::RefPtr<Gdk::Window> window = preset_scrolledbox->get_toplevel()->get_window();
+    if (load_new || ! dest->query_exists()) {
+        Gdk::Cursor cursor(Gdk::WATCH);
+        window->set_cursor(cursor);
+        if (dest->query_exists()) {
+            Gtk::MessageDialog *d = new Gtk::MessageDialog(*dynamic_cast<Gtk::Window*>(online_preset->get_toplevel()),
+             "Do you wont to check for new presets from\n https://musical-artifacts.com ? \n Note, that may take a while",
+              false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO, true);
+            d->set_position(Gtk::WIN_POS_MOUSE);
+            if (d->run() == Gtk::RESPONSE_YES) load = true;
+            delete d;
+        }
+        if (load || ! dest->query_exists()) {
+            if (download_file("https://musical-artifacts.com/artifacts.json?apps=guitarix", options.get_online_config_filename())) {
+                machine.load_online_presets();
+            } else {
+                window->set_cursor(); 
+                return;
+            } 
+        }
+    window->set_cursor(); 
+    }
+    load_new = false;
+    create_preset_menu(load_new);
 }
 
 void PresetWindow::on_online_preset() {
     Glib::signal_idle().connect_once(sigc::mem_fun(*this, &PresetWindow::show_online_preset));
 }
 
-#endif
-
 bool PresetWindow::on_bank_drag_motion(const Glib::RefPtr<Gdk::DragContext>& context, int x, int y, guint timestamp) {
     Gtk::Widget *source_widget = Gtk::Widget::drag_get_source_widget(context);
     if (!source_widget) {
@@ -983,7 +1090,7 @@ void PresetWindow::text_func(Gtk::CellRenderer *cell, const Gtk::TreeModel::iter
 	if (n > 9) {
 	    t = "    " + t;
 	} else {
-	    t = Glib::ustring::compose("%1:  %2", (n == 9 ? 0 : n+1), t);
+	    t = Glib::ustring::compose("%1:  %2", n, t);
 	}
     }
     cell->set_property("text", t);
@@ -1043,8 +1150,8 @@ void PresetWindow::on_preset_edited(const Glib::ustring& path, const Glib::ustri
     }
     // vowel mutation lead to a Glib::markup error when building the menu action,
     // so check for it and avoid them
-    if (newname.find_first_of("ÜüÖöÄä") != Glib::ustring::npos) {
-	gx_print_error("PresetWindow", "Vowel mutation isn't allowed in preset names, please choose a name without (ÜüÖöÄä)");
+    if (newname.find_first_of("ÜüūûúùÖöøøōôóòǫ°Ääæǣāàáâąþćēêèéīîíìȳŷýỳźżłśñ&%$§!?*#|<>/~_") != Glib::ustring::npos) {
+	gx_print_error("PresetWindow", "Vowel mutation isn't allowed in preset names, please choose a name without \n(ÜüūûúùÖöøøōôóòǫ°Ääæǣāàáâąþēêèéīîíìȳŷýỳñ&%$§!?*#|<>/~_)");
     reset_edit(*preset_treeview->get_column(0));
 	return;        
     }
