@@ -145,6 +145,7 @@ void StackBoxBuilder::get_box(const std::string& name, Gtk::Widget*& mainbox, Gt
 	{ "oscilloscope", &StackBoxBuilder::make_rackbox_oscilloscope },
 	{ "jconv_mono", &StackBoxBuilder::make_rackbox_jconv_mono },
 	{ "midi_out", &StackBoxBuilder::make_rackbox_midi_out },
+	{ "seq", &StackBoxBuilder::make_rackbox_sequencer },
 	// stereo
 	{ "jconv", &StackBoxBuilder::make_rackbox_jconv },
     };
@@ -219,6 +220,19 @@ void StackBoxBuilder::loadRackFromBuilder(const Glib::RefPtr<GxBuilder>& bld) {
             break;
         }
     }
+    for (int i = 1; i<12;++i) {
+        Glib::ustring fm = "gxportdisplay" + gx_system::to_string(i);
+        if (bld->has_object(fm)) {
+            Gxw::PortDisplay *regler;
+            bld->find_widget(fm, regler);
+            regler->get_property("var_id",id);
+            if (!id.empty())
+            Glib::signal_timeout().connect(sigc::bind<const std::string>(
+              sigc::mem_fun(*this, &StackBoxBuilder::set_engine_value),id), 60);
+         } else {
+            break;
+        }
+    }
     // find feedback switches and connect a timeout callback to update the UI elements.
     // feedback switches must have the id gxfswitchN were N starts with 1
     for (int i = 1; i<12;++i) {
@@ -357,6 +371,24 @@ void StackBoxBuilder::addJConvButton(const char* label, gx_jconv::IRWindow *irw)
     button->signal_clicked().connect(
 	sigc::mem_fun(*irw, &gx_jconv::IRWindow::reload_and_show));
 }
+void StackBoxBuilder::addSeqButton(const char* label, gx_seq::SEQWindow *seqw) {
+    Gtk::Button *button = new Gtk::Button();
+    button->set_can_default(false);
+    button->set_can_focus(false);
+    Gtk::Label *lab = new Gtk::Label(label);
+    //Pango::FontDescription font = lab->get_style()->get_font();
+    //font.set_size(10*Pango::SCALE);
+    //font.set_weight(Pango::WEIGHT_NORMAL);
+    //lab->modify_font(font);
+    button->add(*manage(lab));
+    //lab->set_name("rack_label_inverse");
+    Gtk::Alignment *al = new Gtk::Alignment(0.0, 0.5, 0.0, 0.0);
+    al->add(*manage(button));
+    al->show_all();
+    fBox.box_pack_start(manage(al), false);
+    button->signal_clicked().connect(
+	sigc::mem_fun(*seqw, &gx_seq::SEQWindow::reload_and_show));
+}
 
 void StackBoxBuilder::set_next_flags(int flags) {
     next_flags = flags;
@@ -535,6 +567,7 @@ void StackBoxBuilder::load_file(const std::string& id, const std::string& idf) {
 				Glib::ustring title = hostname + ": Select loop file";
 				Gtk::FileChooserDialog d( title);
 				d.set_local_only(false);
+				d.property_destroy_with_parent().set_value(true);
 				d.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
 				d.add_button(Gtk::Stock::OK, Gtk::RESPONSE_OK);
 				Glib::ustring loop_dir = machine.get_options().get_loop_dir();
@@ -563,27 +596,65 @@ void StackBoxBuilder::load_file(const std::string& id, const std::string& idf) {
 				} else {
 					d.set_current_folder_uri(Glib::filename_to_uri (loop_dir, hostname));
 				}
-				if (d.run() != Gtk::RESPONSE_OK) {
-					machine.set_parameter_value(id,0.0);
-					machine.signal_parameter_value<float>(id)(0.0);
-					return;
+				d.signal_response().connect(sigc::bind<Gtk::FileChooserDialog*>(sigc::bind<const std::string>(
+					sigc::bind<const std::string>(sigc::mem_fun(*this, &StackBoxBuilder::on_file_chooser_response),idf),id), &d) );
+				d.show();
+				while(machine.get_parameter_value<float>(id)>0) {
+				    //g_main_context_iteration (NULL, true);
+					if (Gtk::Main::iteration(false)) {
+						machine.set_parameter_value(id,0.0);
+						machine.signal_parameter_value<float>(id)(0.0);	
+					}
 				}
-				filename = Glib::filename_from_uri(d.get_uri(), hostname);
-				recent_filename = filename;
-				Gtk::RecentManager::Data data;
-				bool result_uncertain;
-				data.mime_type = Gio::content_type_guess(filename, "", result_uncertain);
-				data.app_name = "guitarix";
-				data.groups.push_back("loopfiles");
-				Gtk::RecentManager::get_default()->add_item(d.get_uri(), data);
-				machine.set_parameter_value(idf,filename);
-				machine.set_parameter_value(id,0.0);
-				machine.signal_parameter_value<float>(id)(0.0);
+				
+			//	if (d.run() != Gtk::RESPONSE_OK) {
+			//		machine.set_parameter_value(id,0.0);
+			//		machine.signal_parameter_value<float>(id)(0.0);
+			//		return;
+			//	}
+			//	filename = Glib::filename_from_uri(d.get_uri(), hostname);
+			//	recent_filename = filename;
+			//	Gtk::RecentManager::Data data;
+			//	bool result_uncertain;
+			//	data.mime_type = Gio::content_type_guess(filename, "", result_uncertain);
+			//	data.app_name = "guitarix";
+			//	data.groups.push_back("loopfiles");
+			//	Gtk::RecentManager::get_default()->add_item(d.get_uri(), data);
+			//	machine.set_parameter_value(idf,filename);
+			//	machine.set_parameter_value(id,0.0);
+			//	machine.signal_parameter_value<float>(id)(0.0);
 			}
 		}
 	}
 }
 
+void StackBoxBuilder::on_file_chooser_response(int response_id, Gtk::FileChooserDialog *d, const std::string& id, const std::string& idf)
+{
+	if( response_id == Gtk::RESPONSE_OK) {
+		static Glib::ustring hostname = "localhost";
+		if (! machine.get_jack()) {
+			hostname = Gio::Resolver::get_default()->lookup_by_address
+					(Gio::InetAddress::create( machine.get_options().get_rpcaddress()));
+		}
+		Glib::ustring filename = Glib::filename_from_uri(d->get_uri(), hostname);
+		Glib::ustring recent_filename = filename;
+		Gtk::RecentManager::Data data;
+		bool result_uncertain;
+		data.mime_type = Gio::content_type_guess(filename, "", result_uncertain);
+		data.app_name = "guitarix";
+		data.groups.push_back("loopfiles");
+		Gtk::RecentManager::get_default()->add_item(d->get_uri(), data);
+		d->hide();
+		machine.set_parameter_value(idf,filename);
+		machine.set_parameter_value(id,0.0);
+		machine.signal_parameter_value<float>(id)(0.0);	
+	} else {
+		d->hide();
+		machine.set_parameter_value(id,0.0);
+		machine.signal_parameter_value<float>(id)(0.0);
+	}
+ }
+
 void StackBoxBuilder::load_file_f(const std::string& id, const std::string& idf) {
     Glib::signal_timeout().connect_once(
 			sigc::bind<const std::string>(sigc::bind<const std::string>(sigc::mem_fun(this, &StackBoxBuilder::load_file), idf), id),100);
