@@ -499,6 +499,10 @@ void GxMachine::load_preset(gx_system::PresetFileGui *pf, const Glib::ustring& n
 #endif
 }
 
+void GxMachine::load_online_presets() {
+    settings.load_online_presets();
+}
+
 void GxMachine::loadstate() {
     settings.loadstate();
 	if (!options.get_setbank().empty()) {
@@ -784,8 +788,9 @@ void GxMachine::midi_set_current_control(int v) {
     engine.controller_map.set_current_control(v);
 }
 
-void GxMachine::midi_modifyCurrent(Parameter& param, float lower, float upper, bool toggle) {
-    engine.controller_map.modifyCurrent(param, lower, upper, toggle);
+void GxMachine::midi_modifyCurrent(Parameter& param, float lower, float upper,
+                                   bool toggle, int toggle_behaviour) {
+    engine.controller_map.modifyCurrent(param, lower, upper, toggle, toggle_behaviour);
 }
 
 int GxMachine::midi_param2controller(Parameter& param, const MidiController** p) {
@@ -943,6 +948,8 @@ inline void debug_trace_param(Parameter *p) {
 	cerr << p->getString().get_value();
     } else if (dynamic_cast<JConvParameter*>(p) != 0) {
 	cerr << dynamic_cast<JConvParameter*>(p)->get_value().getFullIRPath();
+    } else if (dynamic_cast<SeqParameter*>(p) != 0) {
+	cerr << dynamic_cast<SeqParameter*>(p)->get_value();
     } else {
 	assert(false);
     }
@@ -1031,6 +1038,8 @@ void GxMachineRemote::param_signal(Parameter *p) {
 	jw->write(p->getString().get_value());
     } else if (dynamic_cast<JConvParameter*>(p) != 0) {
 	dynamic_cast<JConvParameter*>(p)->get_value().writeJSON(*jw);
+    } else if (dynamic_cast<SeqParameter*>(p) != 0) {
+	dynamic_cast<SeqParameter*>(p)->get_value().writeJSON(*jw);
     } else {
 	assert(false);
     }
@@ -1080,6 +1089,10 @@ void GxMachineRemote::parameter_changed(gx_system::JsonStringParser *jp) {
 	JConvParameter* pj = dynamic_cast<JConvParameter*>(&p);
 	pj->readJSON_value(*jp);
 	pj->setJSON_value();
+    } else if (dynamic_cast<SeqParameter*>(&p) != 0) {
+	SeqParameter* pj = dynamic_cast<SeqParameter*>(&p);
+	pj->readJSON_value(*jp);
+	pj->setJSON_value();
     } else {
 	cerr << "change special type parameter " << p.id() << endl;
     }
@@ -1931,6 +1944,12 @@ void GxMachineRemote::load_preset(gx_system::PresetFileGui *pf, const Glib::ustr
 #endif
 }
 
+void GxMachineRemote::load_online_presets() {
+    START_NOTIFY(set_online_presets);
+    SEND();
+    // FIXME
+}
+
 void GxMachineRemote::loadstate() {
     /* noop */
 }
@@ -2295,6 +2314,9 @@ void GxMachineRemote::set_init_values() {
 	} else if (dynamic_cast<JConvParameter*>(i->second) != 0) {
 	    JConvParameter* pj = dynamic_cast<JConvParameter*>(i->second);
 	    pj->signal_changed()(&pj->get_value());
+	} else if (dynamic_cast<SeqParameter*>(i->second) != 0) {
+	    SeqParameter* pj = dynamic_cast<SeqParameter*>(i->second);
+	    pj->signal_changed()(&pj->get_value());
 	}
     }
     selection_changed(); // give preset window a chance to catch up on current preset
@@ -2327,6 +2349,11 @@ void GxMachineRemote::set_init_values() {
 		sigc::hide(
 		    sigc::bind(
 			sigc::mem_fun(this, &GxMachineRemote::param_signal), i->second)));
+	} else if (dynamic_cast<SeqParameter*>(i->second) != 0) {
+	    dynamic_cast<SeqParameter*>(i->second)->signal_changed().connect(
+		sigc::hide(
+		    sigc::bind(
+			sigc::mem_fun(this, &GxMachineRemote::param_signal), i->second)));
 	}
     }
 }
@@ -2502,12 +2529,13 @@ void GxMachineRemote::midi_set_current_control(int v) {
     SEND();
 }
 
-void GxMachineRemote::midi_modifyCurrent(Parameter& param, float lower, float upper, bool toggle) {
+void GxMachineRemote::midi_modifyCurrent(Parameter& param, float lower, float upper, bool toggle, int toggle_behaviour) {
     START_NOTIFY(midi_modifyCurrent);
     jw->write(param.id());
     jw->write(lower);
     jw->write(upper);
     jw->write(toggle);
+    jw->write(toggle_behaviour);
     SEND();
 }
 
