@@ -105,6 +105,7 @@ class FileParameter;
 class Parameter: boost::noncopyable {
 public:
     enum ctrl_type { None, Continuous, Switch, Enum };
+    enum toggle_type { OnOff = 0, Constant = 1, _Count = 2 };
 private:
     virtual bool midi_set(float n, float high, float llimit, float ulimit); //RT
     virtual bool midi_set_bpm(float n, float high, float llimit, float ulimit); //RT
@@ -602,7 +603,7 @@ class ParamMap: boost::noncopyable {
     }
     inline FloatParameter *reg_non_midi_par(const string& id, float *val, bool preset,
 				 float std = 0, float lower = 0, float upper = 1, float step = 0) {
-	FloatParameter *p = new FloatParameter(id, "", Parameter::None, preset, val, std, lower, upper, step, false, replace_mode);
+	FloatParameter *p = new FloatParameter(id, "", Parameter::Continuous, preset, val, std, lower, upper, step, false, replace_mode);
 	insert(p);
 	return p;
     }
@@ -672,12 +673,15 @@ class MidiController {
     Parameter *param; //RT
     float _lower, _upper; //RT
     bool toggle; //RT
+    int _toggle_behaviour;
+
  public:
-    MidiController(Parameter& p, float l, float u, bool t=false):
-        param(&p), _lower(l), _upper(u), toggle(t) {}
+    MidiController(Parameter& p, float l, float u, bool t=false, int tt=0):
+        param(&p), _lower(l), _upper(u), toggle(t), _toggle_behaviour(tt) {}
     float lower() const { return _lower; }
     float upper() const { return _upper; }
     bool is_toggle() const { return toggle; }
+    int toggle_behaviour() const { return _toggle_behaviour; }
     bool hasParameter(const Parameter& p) const { return *param == p; }
     Parameter& getParameter() const { return *param; }
     static MidiController *readJSON(gx_system::JsonParser& jp, ParamMap& param);
@@ -732,6 +736,7 @@ private:
     ControllerArray        map; //RT
     int                    last_midi_control_value[ControllerArray::array_size]; //RT
     int                    last_midi_control; //RT
+    int                    changed_midi_control_value[ControllerArray::array_size]; //RT
     volatile gint          program_change; //RT
     volatile gint          mute_change; //RT
     volatile gint          bank_change; //RT
@@ -763,14 +768,14 @@ public:
     void set_ctr_val(int ctr, int val); //RT
     void set_bpm_val(unsigned int val); //RT
     void deleteParameter(Parameter& param);
-    void modifyCurrent(Parameter& param, float lower, float upper, bool toggle);
+    void modifyCurrent(Parameter& param, float lower, float upper, bool toggle, int toggle_behaviour);
     int param2controller(Parameter& param, const MidiController** p) {
 	return map.param2controller(param, p); }
     void writeJSON(gx_system::JsonWriter& jw) const { map.writeJSON(jw); }
     int get_last_midi_control_value(unsigned int n) {
 	assert(n < ControllerArray::array_size); return last_midi_control_value[n]; } //RT
     void set_last_midi_control_value(unsigned int n, int v) {
-	assert(n < ControllerArray::array_size); last_midi_control_value[n] = v; } //RT
+	assert(n < ControllerArray::array_size); last_midi_control_value[n] = v; changed_midi_control_value[n] = 1; } //RT
     void set_controller_array(const ControllerArray& m);
     void remove_controlled_parameters(paramlist& plist, const ControllerArray *m);
     sigc::signal<void>& signal_changed() { return changed; }
