@@ -112,6 +112,7 @@ public:
     virtual gx_system::PresetFileGui* get_bank_file(const Glib::ustring& bank) const = 0;
     virtual Glib::ustring get_bank_name(int n) = 0;
     virtual void load_preset(gx_system::PresetFileGui *pf, const Glib::ustring& name) = 0;
+    virtual void load_online_presets()  = 0;
     virtual void msend_midi_cc(int cc, int pgn, int bgn, int num) = 0;
     virtual void loadstate() = 0;
     virtual int bank_size() = 0;
@@ -175,7 +176,7 @@ public:
     virtual midi_controller_list& midi_get(int n) = 0;
     virtual void midi_deleteParameter(Parameter& param) = 0;
     virtual void midi_set_current_control(int v) = 0;
-    virtual void midi_modifyCurrent(Parameter& param, float lower, float upper, bool toggle) = 0;
+    virtual void midi_modifyCurrent(Parameter& param, float lower, float upper, bool toggle, int toggle_behaviour) = 0;
     virtual int midi_param2controller(Parameter& param, const MidiController** p) = 0;
     // Convolver
     virtual void reload_impresp_list(const std::string& path) = 0;
@@ -294,6 +295,7 @@ public:
     virtual gx_system::PresetFileGui* get_bank_file(const Glib::ustring& bank) const;
     virtual Glib::ustring get_bank_name(int n);
     virtual void load_preset(gx_system::PresetFileGui *pf, const Glib::ustring& name);
+    virtual void load_online_presets() ;
     virtual void msend_midi_cc(int cc, int pgn, int bgn, int num);
     virtual void loadstate();
     virtual int bank_size();
@@ -356,7 +358,7 @@ public:
     virtual midi_controller_list& midi_get(int n);
     virtual void midi_deleteParameter(Parameter& param);
     virtual void midi_set_current_control(int v);
-    virtual void midi_modifyCurrent(Parameter& param, float lower, float upper, bool toggle);
+    virtual void midi_modifyCurrent(Parameter& param, float lower, float upper, bool toggle, int toggle_behaviour);
     virtual int midi_param2controller(Parameter& param, const MidiController** p);
     // Convolver
     virtual void reload_impresp_list(const std::string& path);
@@ -473,6 +475,7 @@ public:
     virtual gx_system::PresetFileGui* get_bank_file(const Glib::ustring& bank) const;
     virtual Glib::ustring get_bank_name(int n);
     virtual void load_preset(gx_system::PresetFileGui *pf, const Glib::ustring& name);
+    virtual void load_online_presets() ;
     virtual void msend_midi_cc(int cc, int pgn, int bgn, int num);
     virtual void loadstate();
     virtual int bank_size();
@@ -535,7 +538,7 @@ public:
     virtual midi_controller_list& midi_get(int n);
     virtual void midi_deleteParameter(Parameter& param);
     virtual void midi_set_current_control(int v);
-    virtual void midi_modifyCurrent(Parameter& param, float lower, float upper, bool toggle);
+    virtual void midi_modifyCurrent(Parameter& param, float lower, float upper, bool toggle, int toggle_behaviour);
     virtual int midi_param2controller(Parameter& param, const MidiController** p);
     // Convolver
     virtual void reload_impresp_list(const std::string& path);
